@@ -1,5 +1,5 @@
 /***************************************************************************
-* Copyright (c) 2016, Johan Mabille and Sylvain Corlay                     *
+* Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht    *
 *                                                                          *
 * Distributed under the terms of the BSD 3-Clause License.                 *
 *                                                                          *
@@ -58,7 +58,6 @@ namespace xt
     class xgenerator : public xexpression<xgenerator<F, R, S>>,
                        public xexpression_const_iterable<xgenerator<F, R, S>>
     {
-
     public:
 
         using self_type = xgenerator<F, R, S>;
@@ -82,7 +81,7 @@ namespace xt
 
         static constexpr layout_type static_layout = layout_type::any;
         static constexpr bool contiguous_layout = true;
-        
+
         template <class Func>
         xgenerator(Func&& f, const S& shape) noexcept;
 
@@ -108,7 +107,7 @@ namespace xt
         template <class O>
         const_stepper stepper_begin(const O& shape) const noexcept;
         template <class O>
-        const_stepper stepper_end(const O& shape) const noexcept;
+        const_stepper stepper_end(const O& shape, layout_type) const noexcept;
 
     private:
 
@@ -261,7 +260,7 @@ namespace xt
 
     template <class F, class R, class S>
     template <class O>
-    inline auto xgenerator<F, R, S>::stepper_end(const O& shape) const noexcept -> const_stepper
+    inline auto xgenerator<F, R, S>::stepper_end(const O& shape, layout_type) const noexcept -> const_stepper
     {
         size_type offset = shape.size() - dimension();
         return const_stepper(this, offset, true);
