@@ -44,7 +44,7 @@ namespace xt
         ASSERT_EQ(m_assigned[{49}], 49);
         ASSERT_EQ(m_assigned[{29}], 29);
 
-        xarray<double> b({ 2, 50 }, 1.);
+        xarray<double> b({2, 50}, 1.);
         xarray<double> res = b + ls;
         ASSERT_EQ(50, res(1, 49));
     }
@@ -139,7 +139,7 @@ namespace xt
         ASSERT_EQ(ls.shape(), expected_shape);
         ASSERT_EQ(ls[{0}], 100);
 
-        double at_1 = std::pow(10.0, (2.0 + 1.0/3.0));
+        double at_1 = std::pow(10.0, (2.0 + 1.0 / 3.0));
         ASSERT_EQ(ls(1), at_1);
 
         ASSERT_EQ(ls(3), 1000);
@@ -172,8 +172,7 @@ namespace xt
 
     TEST(xbuilder, concatenate)
     {
-        xarray<double> a = arange<double>(12);
-        a.reshape({2, 2, 3});
+        xarray<double> a = {{{0, 1, 2}, {3, 4, 5}}, {{6, 7, 8}, {9, 10, 11}}};
 
         auto c = concatenate(xtuple(a, a, a), 2);
 
@@ -183,8 +182,8 @@ namespace xt
         ASSERT_EQ(11, c(1, 1, 2));
         ASSERT_EQ(11, c(1, 1, 5));
 
-        xarray<double> e = {{1,2,3}};
-        xarray<double> f = {{2,3,4}};
+        xarray<double> e = {{1, 2, 3}};
+        xarray<double> f = {{2, 3, 4}};
         xarray<double> k = concatenate(xtuple(e, f));
         xarray<double> l = concatenate(xtuple(e, f), 1);
 
@@ -202,8 +201,7 @@ namespace xt
 
     TEST(xbuilder, stack)
     {
-        xarray<double> a = arange<double>(12);
-        a.reshape({2, 2, 3});
+        xarray<double> a = {{{0, 1, 2}, {3, 4, 5}}, {{6, 7, 8}, {9, 10, 11}}};
 
         auto c = stack(xtuple(a, a, a), 2);
 
@@ -216,7 +214,7 @@ namespace xt
         ASSERT_EQ(11, c(1, 1, 2, 2));
 
         auto e = arange(1, 4);
-        xarray<double> f = {2,3,4};
+        xarray<double> f = {2, 3, 4};
         xarray<double> k = stack(xtuple(e, f));
         xarray<double> l = stack(xtuple(e, f), 1);
 
@@ -229,8 +227,7 @@ namespace xt
         ASSERT_EQ(3, l(2, 0));
 
         auto t = stack(xtuple(arange(3), arange(3, 6), arange(6, 9)));
-        xarray<double> ar = arange(9);
-        ar.reshape({3, 3});
+        xarray<double> ar = {{0, 1, 2}, {3, 4, 5}, {6, 7, 8}};
         ASSERT_TRUE(t == ar);
     }
 
@@ -245,8 +242,7 @@ namespace xt
 
     TEST(xbuilder, triu)
     {
-        xarray<double> e = xt::arange<double>(1, 10);
-        e.reshape({3, 3});
+        xarray<double> e = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}};
         xarray<double> t = xt::triu(e);
 
         xarray<double> expected = {{1, 2, 3},
@@ -276,8 +272,7 @@ namespace xt
 
     TEST(xbuilder, tril)
     {
-        xarray<double> e = xt::arange<double>(1, 10);
-        e.reshape({3, 3});
+        xarray<double> e = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}};
         xarray<double> t = xt::tril(e);
 
         xarray<double> expected = {{1, 0, 0},
@@ -307,15 +302,14 @@ namespace xt
 
     TEST(xbuilder, diagonal)
     {
-        xarray<double> e = xt::arange<double>(1, 10);
-        e.reshape({3, 3});
+        xarray<double> e = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}};
+
         xarray<double> t = xt::diagonal(e);
 
         xarray<double> expected = {1, 5, 9};
         ASSERT_EQ(expected, t);
 
-        xt::xarray<double> f = xt::arange(12);
-        f.reshape({4, 3});
+        xt::xarray<double> f = {{0, 1, 2}, {3, 4, 5}, {6, 7, 8}, {9, 10, 11}};
 
         xarray<double> exp_1 = {1, 5};
         ASSERT_TRUE(all(equal(exp_1, xt::diagonal(f, 1))));
@@ -329,23 +323,25 @@ namespace xt
 
     TEST(xbuilder, diagonal_advanced)
     {
-        xarray<double> e = xt::arange<double>(0, 24);
-        e.reshape({2, 2, 2, 3});
+        xarray<double> e = {{{{0, 1, 2}, {3, 4, 5}}, 
+                             {{6, 7, 8}, {9, 10, 11}}},
+                            {{{12, 13, 14}, {15, 16, 17}}, 
+                             {{18, 19, 20}, {21, 22, 23}}}};
 
         xarray<double> d1 = xt::diagonal(e);
 
-        xarray<double> expected = {{{ 0, 18},
-                                    { 1, 19},
-                                    { 2, 20}},
-                                   {{ 3, 21},
-                                    { 4, 22},
-                                    { 5, 23}}};
+        xarray<double> expected = {{{0, 18},
+                                    {1, 19},
+                                    {2, 20}},
+                                   {{3, 21},
+                                    {4, 22},
+                                    {5, 23}}};
         ASSERT_EQ(expected, d1);
 
         std::vector<double> d2 = {6, 7, 8, 9, 10, 11};
         xarray<double> expected_2;
         expected_2.reshape({2, 3, 1});
-        std::copy(d2.begin(), d2.end(), expected_2.data().begin());
+        std::copy(d2.begin(), d2.end(), expected_2.template xbegin<layout_type::row_major>());
 
         xarray<double> t2 = xt::diagonal(e, 1);
         ASSERT_EQ(expected_2, t2);
@@ -353,16 +349,14 @@ namespace xt
         std::vector<double> d3 = {3, 9, 15, 21};
         xarray<double> expected_3;
         expected_3.reshape({2, 2, 1});
-        std::copy(d3.begin(), d3.end(), expected_3.data().begin());
+        std::copy(d3.begin(), d3.end(), expected_3.template xbegin<layout_type::row_major>());
         xarray<double> t3 = xt::diagonal(e, -1, 2, 3);
         ASSERT_EQ(expected_3, t3);
-
     }
 
     TEST(xbuilder, diag)
     {
-        xarray<double> e = xt::arange<double>(1, 10);
-        e.reshape({3, 3});
+        xarray<double> e = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}};
         xarray<double> t = xt::diag(xt::diagonal(e));
         xarray<double> expected = xt::eye(3) * e;
 
@@ -371,10 +365,9 @@ namespace xt
 
     TEST(xbuilder, flipud)
     {
-        xarray<double> e = xt::arange<double>(1, 10);
-        e.reshape({3, 3});
+        xarray<double> e = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}};
         xarray<double> t = xt::flip(e, 0);
-        xarray<double> expected = {{7,8,9},{4,5,6},{1,2,3}};
+        xarray<double> expected = {{7, 8, 9}, {4, 5, 6}, {1, 2, 3}};
         ASSERT_EQ(expected, t);
 
         xindex idx = {0, 0};
@@ -382,22 +375,21 @@ namespace xt
         ASSERT_EQ(2, t(2, 1));
         ASSERT_EQ(7, t.element(idx.begin(), idx.end()));
 
-        xarray<double> f = xt::arange<double>(12);
-        f.reshape({2, 2, 3});
+        xarray<double> f = {{{0, 1, 2}, {3, 4, 5}}, {{6, 7, 8}, {9, 10, 11}}};
+
         xarray<double> ft = xt::flip(f, 0);
-        xarray<double> expected_2 = {{{ 6,  7,  8},
-                                      { 9, 10, 11}},
-                                     {{ 0,  1,  2},
-                                      { 3,  4,  5}}};
+        xarray<double> expected_2 = {{{6, 7, 8},
+                                      {9, 10, 11}},
+                                     {{0, 1, 2},
+                                      {3, 4, 5}}};
         ASSERT_EQ(expected_2, ft);
     }
 
     TEST(xbuilder, fliplr)
     {
-        xarray<double> e = xt::arange<double>(1, 10);
-        e.reshape({3, 3});
+        xarray<double> e = {{1, 2, 3}, {4, 5, 6}, {7, 8, 9}};
         xarray<double> t = xt::flip(e, 1);
-        xarray<double> expected = {{3,2,1},{6,5,4},{9,8,7}};
+        xarray<double> expected = {{3, 2, 1}, {6, 5, 4}, {9, 8, 7}};
         ASSERT_EQ(expected, t);
 
         xindex idx = {0, 0};
@@ -405,13 +397,13 @@ namespace xt
         ASSERT_EQ(8, t(2, 1));
         ASSERT_EQ(3, t.element(idx.begin(), idx.end()));
 
-        xarray<double> f = xt::arange<double>(12);
-        f.reshape({2, 2, 3});
+        xarray<double> f = {{{0, 1, 2}, {3, 4, 5}}, {{6, 7, 8}, {9, 10, 11}}};
+
         xarray<double> ft = xt::flip(f, 1);
-        xarray<double> expected_2 = {{{  3,  4,  5},
-                                      {  0,  1,  2}},
-                                     {{  9, 10, 11},
-                                      {  6,  7,  8}}};
+        xarray<double> expected_2 = {{{3, 4, 5},
+                                      {0, 1, 2}},
+                                     {{9, 10, 11},
+                                      {6, 7, 8}}};
 
         ASSERT_EQ(expected_2, ft);
         auto flipped_range = xt::flip(xt::stack(xt::xtuple(arange<double>(2), arange<double>(2))), 1);
