@@ -21,8 +21,8 @@ namespace xt
     {
         view_shape_type shape = {3, 4};
         xarray<double> a(shape);
-        std::vector<double> data {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::vector<double> data{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
         auto view1 = dynamic_view(a, slice_vector(a, 1, range(1, 4)));
         EXPECT_EQ(a(1, 1), view1(0));
@@ -64,7 +64,7 @@ namespace xt
     TEST(xdynview, three_dimensional)
     {
         view_shape_type shape = {3, 4, 2};
-        std::vector<double> data {
+        std::vector<double> data{
             1, 2,
             3, 4,
             5, 6,
@@ -72,7 +72,7 @@ namespace xt
 
             9, 10,
             11, 12,
-            21, 22, 
+            21, 22,
             23, 24,
 
             25, 26,
@@ -81,7 +81,7 @@ namespace xt
             211, 212
         };
         xarray<double> a(shape);
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
         auto view1 = dynamic_view(a, slice_vector(a, 1));
         EXPECT_EQ(2, view1.dimension());
@@ -91,7 +91,7 @@ namespace xt
         EXPECT_EQ(a(1, 0, 1), view1(0, 1));
         EXPECT_EQ(a(1, 1, 0), view1(1, 0));
         EXPECT_EQ(a(1, 1, 1), view1(1, 1));
-        
+
         std::array<std::size_t, 2> idx = {1, 1};
         EXPECT_EQ(a(1, 1, 1), view1.element(idx.cbegin(), idx.cend()));
     }
@@ -102,7 +102,7 @@ namespace xt
         xarray<double> a(shape);
         std::vector<double> data {1,  2,  3,  4,  5,  6,  7,  8,  9,  10, 11, 12,
                                   13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23, 24};
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
         auto view1 = dynamic_view(a, slice_vector(a, range(0, 2), 1, range(1, 4)));
         auto iter = view1.begin();
@@ -141,13 +141,13 @@ namespace xt
     {
         view_shape_type shape = {3, 4};
         xarray<int> a(shape);
-        std::vector<int> data {1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::vector<int> data{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
-        view_shape_type shape2 = { 3 };
+        view_shape_type shape2 = {3};
         xarray<int> b(shape2);
-        std::vector<int> data2 = { 1, 2, 3 };
-        std::copy(data2.cbegin(), data2.cend(), b.begin());
+        std::vector<int> data2 = {1, 2, 3};
+        std::copy(data2.cbegin(), data2.cend(), b.template xbegin<layout_type::row_major>());
 
         auto func = dynamic_view(a, slice_vector(a, 1, range(1, 4))) + b;
         auto iter = func.begin();
@@ -164,9 +164,9 @@ namespace xt
 
     TEST(xdynview, xdynview_on_xtensor)
     {
-        xtensor<int, 2> a({ 3, 4 });
-        std::vector<int> data{ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 };
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        xtensor<int, 2> a({3, 4});
+        std::vector<int> data{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+        std::copy(data.cbegin(), data.cend(), a.xbegin<layout_type::row_major>());
 
         auto view1 = dynamic_view(a, slice_vector(a, 1, range(1, 4)));
         EXPECT_EQ(a(1, 1), view1(0));
@@ -182,7 +182,7 @@ namespace xt
         ++iter;
         EXPECT_EQ(8, *iter);
 
-        xarray<int> b({ 3 }, 2);
+        xarray<int> b({3}, 2);
         xtensor<int, 1> res = view1 + b;
         EXPECT_EQ(8, res(0));
         EXPECT_EQ(9, res(1));
@@ -191,19 +191,19 @@ namespace xt
 
     TEST(xdynview, const_view)
     {
-        const xtensor<double, 3> arr{ {1, 2, 3}, 2.5 };
-        xtensor<double, 2> arr2{ {2, 3}, 0.0 };
-        xtensor<double, 2> ref{ {2, 3}, 2.5 };
+        const xtensor<double, 3> arr{{1, 2, 3}, 2.5};
+        xtensor<double, 2> arr2{{2, 3}, 0.0};
+        xtensor<double, 2> ref{{2, 3}, 2.5};
         arr2 = dynamic_view(arr, slice_vector(arr, 0));
         EXPECT_EQ(ref, arr2);
     }
 
     TEST(xdynview, newaxis)
     {
-        view_shape_type shape = { 3, 4 };
+        view_shape_type shape = {3, 4};
         xarray<double> a(shape);
-        std::vector<double> data{ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 };
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::vector<double> data{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
         auto view1 = dynamic_view(a, slice_vector(a, all(), newaxis(), all()));
         EXPECT_EQ(a(1, 1), view1(1, 0, 1));
@@ -241,19 +241,19 @@ namespace xt
         EXPECT_EQ(a(1, 2), view6(2, 0));
         EXPECT_EQ(2, view6.dimension());
 
-        std::array<std::size_t, 3> idx1 = { 1, 0, 2 };
+        std::array<std::size_t, 3> idx1 = {1, 0, 2};
         EXPECT_EQ(a(1, 2), view1.element(idx1.begin(), idx1.end()));
 
-        std::array<std::size_t, 3> idx2 = { 1, 2, 0 };
+        std::array<std::size_t, 3> idx2 = {1, 2, 0};
         EXPECT_EQ(a(1, 2), view2.element(idx2.begin(), idx2.end()));
     }
 
     TEST(xdynview, newaxis_iterating)
     {
-        view_shape_type shape = { 3, 4 };
+        view_shape_type shape = {3, 4};
         xarray<double> a(shape);
-        std::vector<double> data{ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 };
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::vector<double> data{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
         auto view1 = dynamic_view(a, slice_vector(a, all(), all(), newaxis()));
         auto iter1 = view1.begin();
@@ -318,22 +318,22 @@ namespace xt
 
     TEST(xdynview, newaxis_function)
     {
-        view_shape_type shape = { 3, 4 };
+        view_shape_type shape = {3, 4};
         xarray<double> a(shape);
-        std::vector<double> data{ 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12 };
-        std::copy(data.cbegin(), data.cend(), a.begin());
+        std::vector<double> data{1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12};
+        std::copy(data.cbegin(), data.cend(), a.template xbegin<layout_type::row_major>());
 
         xarray<double> b(view_shape_type(1, 4));
         auto data_end = data.cbegin();
         data_end += 4;
-        std::copy(data.cbegin(), data_end, b.begin());
+        std::copy(data.cbegin(), data_end, b.template xbegin<layout_type::row_major>());
 
         auto v = dynamic_view(b, slice_vector(b, newaxis(), all()));
         xarray<double> res = a + v;
 
-        std::vector<double> data2{ 2, 4, 6, 8, 6, 8, 10, 12, 10, 12, 14, 16 };
+        std::vector<double> data2{2, 4, 6, 8, 6, 8, 10, 12, 10, 12, 14, 16};
         xarray<double> expected(shape);
-        std::copy(data2.cbegin(), data2.cend(), expected.begin());
+        std::copy(data2.cbegin(), data2.cend(), expected.template xbegin<layout_type::row_major>());
 
         EXPECT_EQ(expected, res);
     }
@@ -378,4 +378,4 @@ namespace xt
         t v8e = {3, 5};
         EXPECT_TRUE(v8e == v8);
     }
-}
\ No newline at end of file
+}
